Learn R Programming

coefficientalpha (version 0.2.6)

coefficientalpha-package: Robust Cronbach's alpha with missing and non-normal data

Description

An R package to calculate coefficient alpha with missing data and non-normal data. Robust standard error and confidence interval are also provided.

Arguments

Details

ll{ Package: coefficientalpha Type: Package Version: 0.1 Date: 2013-01-22 License: GPL }

References

Zhang, Z. & Yuan, K.-H. (2013). Robust Cronbach's alpha.