Learn R Programming

coefficientalpha (version 0.2.6)

rsem.Ascov: Sandwich-type covariance matrix

Description

Returns the sandwich type covariance matrix. This function is not intended to use seperately from the rsem.emmusig function.

Usage

rsem.Ascov(xpattern, musig, varphi=.1)

Arguments

xpattern
Missing data pattern output from rsem.pattern.
musig
Robust mean and covariance matrix from rsem.emmusig
varphi
Proportion of data to be down-weighted. Default is 0.1.

Value

  • AbetaA matrix
  • BbetaB matrix
  • GammaSandwich type covariance matrix

Details

Data should be a matrix. To change a data frame to a matrix, using data.matrix(x).

See Also

rsem.emmusig