Learn R Programming

coefficientalpha (version 0.2.6)

rsem.emmusig: Robust mean and covariance matrix using Huber-type weight

Description

Robust mean and covariance matrix using Huber-type weight.

Usage

rsem.emmusig(xpattern, varphi=.1, max.it=1000, st='i')

Arguments

xpattern
Missing data pattern output from rsem.pattern.
varphi
Proportion of data to be down-weighted. Default is 0.1.
max.it
Maximum number of iterations for EM. Default is 1000
st
Starting values for EM algorithm. The default is 0 for mean and I for covariance. Alternative, the starting values can be estimated according to MCD.

Value

  • errError code. 0: good. 1: maximum iterations are exceeded.
  • muMean vector
  • sigmaCovariance matrix
  • weightweight used in robust mean and covariance estimation.

Details

Estimate mean and covariance matrix using the expectation robust (ER) algorithm.

References

Yuan, K.-H., & Zhang, Z. (2012). Robust Structural Equation Modeling with Missing Data and Auxiliary Variables. Psychometrika, 77(4), 803-826.

See Also

rsem.emmusig