Learn R Programming

coefficientalpha (version 0.2.6)

rsem.pattern: Obtaining missing data patterns

Description

This function obtains the missing data patterns and the number of cases in each patterns. It also tells the number of observed variables and their indices for each pattern.

Usage

rsem.pattern(x, print=FALSE)

Arguments

x
A matrix as data
print
Whether to print the missing data pattern. The default is FALSE.

Value

  • xData ordered according to missing data pattern
  • misinfoMissing data pattern matrix
  • mispatMissing data pattern in better readable form.
  • yThe original data.

Details

The missing data pattern matrix has 2+p columns. The first column is the number cases in that pattern. The second column is the number of observed variables. The last p columns are a matrix with 1 denoting observed data and 0 denoting missing data.

In addition, a matrix of 0/1 is also used to indicate missing data. 1 means missing and 0 means observed.

References

Yuan, K.-H., & Zhang, Z. (2012). Robust Structural Equation Modeling with Missing Data and Auxiliary Variables. Psychometrika, 77(4), 803-826.